# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetGatewayCacheDisksResult',
    'AwaitableGetGatewayCacheDisksResult',
    'get_gateway_cache_disks',
    'get_gateway_cache_disks_output',
]

@pulumi.output_type
class GetGatewayCacheDisksResult:
    """
    A collection of values returned by getGatewayCacheDisks.
    """
    def __init__(__self__, disks=None, gateway_id=None, id=None, ids=None, output_file=None, status=None):
        if disks and not isinstance(disks, list):
            raise TypeError("Expected argument 'disks' to be a list")
        pulumi.set(__self__, "disks", disks)
        if gateway_id and not isinstance(gateway_id, str):
            raise TypeError("Expected argument 'gateway_id' to be a str")
        pulumi.set(__self__, "gateway_id", gateway_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, int):
            raise TypeError("Expected argument 'status' to be a int")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def disks(self) -> Sequence['outputs.GetGatewayCacheDisksDiskResult']:
        return pulumi.get(self, "disks")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> str:
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[int]:
        return pulumi.get(self, "status")


class AwaitableGetGatewayCacheDisksResult(GetGatewayCacheDisksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewayCacheDisksResult(
            disks=self.disks,
            gateway_id=self.gateway_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            status=self.status)


def get_gateway_cache_disks(gateway_id: Optional[str] = None,
                            ids: Optional[Sequence[str]] = None,
                            output_file: Optional[str] = None,
                            status: Optional[int] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewayCacheDisksResult:
    """
    This data source provides the Cloud Storage Gateway Gateway Cache Disks of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.144.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cloudstoragegateway.get_gateway_cache_disks(gateway_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("cloudStorageGatewayGatewayCacheDiskId1", ids.disks[0].id)
    status = alicloud.cloudstoragegateway.get_gateway_cache_disks(gateway_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ],
        status=0)
    pulumi.export("cloudStorageGatewayGatewayCacheDiskId2", status.disks[0].id)
    ```


    :param str gateway_id: The ID of the gateway.
    :param Sequence[str] ids: A list of Gateway Cache Disk IDs.
    :param int status: The status of the resource.
    """
    __args__ = dict()
    __args__['gatewayId'] = gateway_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['status'] = status
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:cloudstoragegateway/getGatewayCacheDisks:getGatewayCacheDisks', __args__, opts=opts, typ=GetGatewayCacheDisksResult).value

    return AwaitableGetGatewayCacheDisksResult(
        disks=__ret__.disks,
        gateway_id=__ret__.gateway_id,
        id=__ret__.id,
        ids=__ret__.ids,
        output_file=__ret__.output_file,
        status=__ret__.status)


@_utilities.lift_output_func(get_gateway_cache_disks)
def get_gateway_cache_disks_output(gateway_id: Optional[pulumi.Input[str]] = None,
                                   ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                   output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                   status: Optional[pulumi.Input[Optional[int]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGatewayCacheDisksResult]:
    """
    This data source provides the Cloud Storage Gateway Gateway Cache Disks of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.144.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cloudstoragegateway.get_gateway_cache_disks(gateway_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("cloudStorageGatewayGatewayCacheDiskId1", ids.disks[0].id)
    status = alicloud.cloudstoragegateway.get_gateway_cache_disks(gateway_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ],
        status=0)
    pulumi.export("cloudStorageGatewayGatewayCacheDiskId2", status.disks[0].id)
    ```


    :param str gateway_id: The ID of the gateway.
    :param Sequence[str] ids: A list of Gateway Cache Disk IDs.
    :param int status: The status of the resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetHostAccountsAccountResult',
    'GetHostGroupsGroupResult',
    'GetHostsHostResult',
    'GetHostsHostProtocolResult',
    'GetInstancesInstanceResult',
    'GetUserGroupsGroupResult',
    'GetUsersUserResult',
]

@pulumi.output_type
class GetHostAccountsAccountResult(dict):
    def __init__(__self__, *,
                 has_password: bool,
                 host_account_id: str,
                 host_account_name: str,
                 host_id: str,
                 id: str,
                 instance_id: str,
                 private_key_fingerprint: str,
                 protocol_name: str):
        """
        :param bool has_password: Whether to set a new password.
        :param str host_account_id: Hosting account ID.
        :param str host_account_name: Specify the new hosting account's name, support the longest 128 characters.
        :param str host_id: Specifies the database where you want to create your hosting account's host ID.
        :param str id: The ID of the Host Account.
        :param str instance_id: Specifies the database where you want to create your hosting account's host bastion host ID of.
        :param str private_key_fingerprint: The situation where the private keys of the fingerprint information.
        :param str protocol_name: Specify the new hosting account of the agreement name. Valid values: USING SSH and RDP.
        """
        pulumi.set(__self__, "has_password", has_password)
        pulumi.set(__self__, "host_account_id", host_account_id)
        pulumi.set(__self__, "host_account_name", host_account_name)
        pulumi.set(__self__, "host_id", host_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "private_key_fingerprint", private_key_fingerprint)
        pulumi.set(__self__, "protocol_name", protocol_name)

    @property
    @pulumi.getter(name="hasPassword")
    def has_password(self) -> bool:
        """
        Whether to set a new password.
        """
        return pulumi.get(self, "has_password")

    @property
    @pulumi.getter(name="hostAccountId")
    def host_account_id(self) -> str:
        """
        Hosting account ID.
        """
        return pulumi.get(self, "host_account_id")

    @property
    @pulumi.getter(name="hostAccountName")
    def host_account_name(self) -> str:
        """
        Specify the new hosting account's name, support the longest 128 characters.
        """
        return pulumi.get(self, "host_account_name")

    @property
    @pulumi.getter(name="hostId")
    def host_id(self) -> str:
        """
        Specifies the database where you want to create your hosting account's host ID.
        """
        return pulumi.get(self, "host_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Host Account.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        Specifies the database where you want to create your hosting account's host bastion host ID of.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="privateKeyFingerprint")
    def private_key_fingerprint(self) -> str:
        """
        The situation where the private keys of the fingerprint information.
        """
        return pulumi.get(self, "private_key_fingerprint")

    @property
    @pulumi.getter(name="protocolName")
    def protocol_name(self) -> str:
        """
        Specify the new hosting account of the agreement name. Valid values: USING SSH and RDP.
        """
        return pulumi.get(self, "protocol_name")


@pulumi.output_type
class GetHostGroupsGroupResult(dict):
    def __init__(__self__, *,
                 comment: str,
                 host_group_id: str,
                 host_group_name: str,
                 id: str,
                 instance_id: str):
        """
        :param str comment: Specify the New Host Group of Notes, Supports up to 500 Characters.
        :param str host_group_id: Host Group ID.
        :param str host_group_name: Specify the New Host Group Name, Supports up to 128 Characters.
        :param str id: The ID of the Host Group.
        :param str instance_id: Specify the New Host Group Where the Bastion Host ID of.
        """
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "host_group_id", host_group_id)
        pulumi.set(__self__, "host_group_name", host_group_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        Specify the New Host Group of Notes, Supports up to 500 Characters.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="hostGroupId")
    def host_group_id(self) -> str:
        """
        Host Group ID.
        """
        return pulumi.get(self, "host_group_id")

    @property
    @pulumi.getter(name="hostGroupName")
    def host_group_name(self) -> str:
        """
        Specify the New Host Group Name, Supports up to 128 Characters.
        """
        return pulumi.get(self, "host_group_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Host Group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        Specify the New Host Group Where the Bastion Host ID of.
        """
        return pulumi.get(self, "instance_id")


@pulumi.output_type
class GetHostsHostResult(dict):
    def __init__(__self__, *,
                 active_address_type: str,
                 comment: str,
                 host_id: str,
                 host_name: str,
                 host_private_address: str,
                 host_public_address: str,
                 id: str,
                 instance_id: str,
                 os_type: str,
                 protocols: Sequence['outputs.GetHostsHostProtocolResult'],
                 source: str,
                 source_instance_id: str):
        """
        :param str active_address_type: Specify the new create a host of address types. Valid values: Public: the IP address of a Public network Private: Private network address.
        :param str comment: Specify a host of notes, supports up to 500 characters.
        :param str host_id: The host ID.
        :param str host_name: Specify the new create a host name of the supports up to 128 characters.
        :param str host_private_address: Specify the new create a host of the private network address, it is possible to use the domain name or IP ADDRESS.
        :param str host_public_address: Specify the new create a host of the IP address of a public network, it is possible to use the domain name or IP ADDRESS.
        :param str id: The ID of the Host.
        :param str instance_id: Specify the new create a host where the Bastion host ID of.
        :param str os_type: Specify the new create the host's operating system. Valid values: Linux Windows.
        :param Sequence['GetHostsHostProtocolArgs'] protocols: The host of the protocol information.
        :param str source: Specify the new create a host of source. Valid values: Local: localhost Ecs:ECS instance Rds:RDS exclusive cluster host.
        :param str source_instance_id: Specify the newly created ECS instance ID or dedicated cluster host ID.
        """
        pulumi.set(__self__, "active_address_type", active_address_type)
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "host_id", host_id)
        pulumi.set(__self__, "host_name", host_name)
        pulumi.set(__self__, "host_private_address", host_private_address)
        pulumi.set(__self__, "host_public_address", host_public_address)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "os_type", os_type)
        pulumi.set(__self__, "protocols", protocols)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "source_instance_id", source_instance_id)

    @property
    @pulumi.getter(name="activeAddressType")
    def active_address_type(self) -> str:
        """
        Specify the new create a host of address types. Valid values: Public: the IP address of a Public network Private: Private network address.
        """
        return pulumi.get(self, "active_address_type")

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        Specify a host of notes, supports up to 500 characters.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="hostId")
    def host_id(self) -> str:
        """
        The host ID.
        """
        return pulumi.get(self, "host_id")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> str:
        """
        Specify the new create a host name of the supports up to 128 characters.
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hostPrivateAddress")
    def host_private_address(self) -> str:
        """
        Specify the new create a host of the private network address, it is possible to use the domain name or IP ADDRESS.
        """
        return pulumi.get(self, "host_private_address")

    @property
    @pulumi.getter(name="hostPublicAddress")
    def host_public_address(self) -> str:
        """
        Specify the new create a host of the IP address of a public network, it is possible to use the domain name or IP ADDRESS.
        """
        return pulumi.get(self, "host_public_address")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Host.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        Specify the new create a host where the Bastion host ID of.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> str:
        """
        Specify the new create the host's operating system. Valid values: Linux Windows.
        """
        return pulumi.get(self, "os_type")

    @property
    @pulumi.getter
    def protocols(self) -> Sequence['outputs.GetHostsHostProtocolResult']:
        """
        The host of the protocol information.
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter
    def source(self) -> str:
        """
        Specify the new create a host of source. Valid values: Local: localhost Ecs:ECS instance Rds:RDS exclusive cluster host.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="sourceInstanceId")
    def source_instance_id(self) -> str:
        """
        Specify the newly created ECS instance ID or dedicated cluster host ID.
        """
        return pulumi.get(self, "source_instance_id")


@pulumi.output_type
class GetHostsHostProtocolResult(dict):
    def __init__(__self__, *,
                 host_finger_print: str,
                 port: int,
                 protocol_name: str):
        """
        :param str host_finger_print: Host fingerprint information, it is possible to uniquely identify a host.
        :param int port: Host the service port of the RDS.
        :param str protocol_name: The host uses the protocol name.
        """
        pulumi.set(__self__, "host_finger_print", host_finger_print)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol_name", protocol_name)

    @property
    @pulumi.getter(name="hostFingerPrint")
    def host_finger_print(self) -> str:
        """
        Host fingerprint information, it is possible to uniquely identify a host.
        """
        return pulumi.get(self, "host_finger_print")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        Host the service port of the RDS.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="protocolName")
    def protocol_name(self) -> str:
        """
        The host uses the protocol name.
        """
        return pulumi.get(self, "protocol_name")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 description: str,
                 id: str,
                 instance_status: str,
                 license_code: str,
                 private_domain: str,
                 public_domain: str,
                 public_network_access: bool,
                 security_group_ids: Sequence[str],
                 user_vswitch_id: str,
                 tags: Optional[Mapping[str, Any]] = None):
        """
        :param str description: The instance's remark.
        :param str id: The instance's id.
        :param str instance_status: The instance's status.
        :param str private_domain: The instance's private domain name.
        :param str public_domain: The instance's public domain name.
        :param bool public_network_access: The instance's public network access configuration.
        :param Sequence[str] security_group_ids: The instance's security group configuration.
        :param str user_vswitch_id: The instance's vSwitch ID.
        :param Mapping[str, Any] tags: A map of tags assigned to the bastionhost instance. It must be in the format:
               ```python
               import pulumi
               import pulumi_alicloud as alicloud
               
               instance = alicloud.bastionhost.get_instances(tags={
                   "tagKey1": "tagValue1",
               })
               ```
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_status", instance_status)
        pulumi.set(__self__, "license_code", license_code)
        pulumi.set(__self__, "private_domain", private_domain)
        pulumi.set(__self__, "public_domain", public_domain)
        pulumi.set(__self__, "public_network_access", public_network_access)
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "user_vswitch_id", user_vswitch_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The instance's remark.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The instance's id.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> str:
        """
        The instance's status.
        """
        return pulumi.get(self, "instance_status")

    @property
    @pulumi.getter(name="licenseCode")
    def license_code(self) -> str:
        return pulumi.get(self, "license_code")

    @property
    @pulumi.getter(name="privateDomain")
    def private_domain(self) -> str:
        """
        The instance's private domain name.
        """
        return pulumi.get(self, "private_domain")

    @property
    @pulumi.getter(name="publicDomain")
    def public_domain(self) -> str:
        """
        The instance's public domain name.
        """
        return pulumi.get(self, "public_domain")

    @property
    @pulumi.getter(name="publicNetworkAccess")
    def public_network_access(self) -> bool:
        """
        The instance's public network access configuration.
        """
        return pulumi.get(self, "public_network_access")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[str]:
        """
        The instance's security group configuration.
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="userVswitchId")
    def user_vswitch_id(self) -> str:
        """
        The instance's vSwitch ID.
        """
        return pulumi.get(self, "user_vswitch_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, Any]]:
        """
        A map of tags assigned to the bastionhost instance. It must be in the format:
        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        instance = alicloud.bastionhost.get_instances(tags={
            "tagKey1": "tagValue1",
        })
        ```
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetUserGroupsGroupResult(dict):
    def __init__(__self__, *,
                 comment: str,
                 id: str,
                 instance_id: str,
                 user_group_id: str,
                 user_group_name: str):
        """
        :param str comment: Specify the New Group of Remark Information. Supports up to 500 Characters.
        :param str id: The ID of the User Group.
        :param str instance_id: Specify the New Group of the Bastion Host of Instance Id.
        :param str user_group_id: The User Group ID.
        :param str user_group_name: Specify the New Group Name. Supports up to 128 Characters.
        """
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "user_group_id", user_group_id)
        pulumi.set(__self__, "user_group_name", user_group_name)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        Specify the New Group of Remark Information. Supports up to 500 Characters.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the User Group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        Specify the New Group of the Bastion Host of Instance Id.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> str:
        """
        The User Group ID.
        """
        return pulumi.get(self, "user_group_id")

    @property
    @pulumi.getter(name="userGroupName")
    def user_group_name(self) -> str:
        """
        Specify the New Group Name. Supports up to 128 Characters.
        """
        return pulumi.get(self, "user_group_name")


@pulumi.output_type
class GetUsersUserResult(dict):
    def __init__(__self__, *,
                 comment: str,
                 display_name: str,
                 email: str,
                 id: str,
                 instance_id: str,
                 mobile: str,
                 mobile_country_code: str,
                 source: str,
                 source_user_id: str,
                 status: str,
                 user_id: str,
                 user_name: str):
        """
        :param str comment: Specify the New of the User That Created the Remark Information. Supports up to 500 Characters.
        :param str display_name: Specify the New Created the User's Display Name. Supports up to 128 Characters.
        :param str email: Specify the New User's Mailbox.
        :param str id: The ID of the User.
        :param str instance_id: You Want to Query the User the Bastion Host ID of.
        :param str mobile: Specify the New of the User That Created a Different Mobile Phone Number from Your.
        :param str mobile_country_code: Specify the New Create User Mobile Phone Number of the International Domain Name. The Default Value Is the CN Value: CN: Mainland China (+86) HK: hong Kong, China (+852) Mo: Macau, China (+853) TW: Taiwan, China (+886) ru: Russian (+7) SG: Singapore (+65) My: malaysia (+60) ID: Indonesia (+62) De: Germany (+49) AU: Australia (+61) US: United States (+1) AE: dubai (+971) JP: Japan (+81) Introducing the Long-Range GB: United Kingdom (+44) in: India (+91) KR: South Korea (+82) Ph: philippines (+63) Ch: Switzerland (+41) Se: Sweden (+46).
        :param str source: Specify the New of the User That Created the Source. Valid Values: Local: Local User RAM: Ram User.
        :param str source_user_id: Specify the Newly Created User Is Uniquely Identified. Indicates That the Parameter Is a Bastion Host Corresponding to the User with the Ram User's Unique Identifier. The Newly Created User Source Grant Permission to a RAM User (That Is, Source Used as a Ram), this Parameter Is Required. You Can Call Access Control of Listusers Interface from the Return Data Userid to Obtain the Parameters.
        :param str status: The status of the resource.
        :param str user_id: The User ID.
        :param str user_name: Specify the New User Name. This Parameter Is Only by Letters, Lowercase Letters, Numbers, and Underscores (_), Supports up to 128 Characters.
        """
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "mobile", mobile)
        pulumi.set(__self__, "mobile_country_code", mobile_country_code)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "source_user_id", source_user_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        Specify the New of the User That Created the Remark Information. Supports up to 500 Characters.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Specify the New Created the User's Display Name. Supports up to 128 Characters.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> str:
        """
        Specify the New User's Mailbox.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the User.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        You Want to Query the User the Bastion Host ID of.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def mobile(self) -> str:
        """
        Specify the New of the User That Created a Different Mobile Phone Number from Your.
        """
        return pulumi.get(self, "mobile")

    @property
    @pulumi.getter(name="mobileCountryCode")
    def mobile_country_code(self) -> str:
        """
        Specify the New Create User Mobile Phone Number of the International Domain Name. The Default Value Is the CN Value: CN: Mainland China (+86) HK: hong Kong, China (+852) Mo: Macau, China (+853) TW: Taiwan, China (+886) ru: Russian (+7) SG: Singapore (+65) My: malaysia (+60) ID: Indonesia (+62) De: Germany (+49) AU: Australia (+61) US: United States (+1) AE: dubai (+971) JP: Japan (+81) Introducing the Long-Range GB: United Kingdom (+44) in: India (+91) KR: South Korea (+82) Ph: philippines (+63) Ch: Switzerland (+41) Se: Sweden (+46).
        """
        return pulumi.get(self, "mobile_country_code")

    @property
    @pulumi.getter
    def source(self) -> str:
        """
        Specify the New of the User That Created the Source. Valid Values: Local: Local User RAM: Ram User.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="sourceUserId")
    def source_user_id(self) -> str:
        """
        Specify the Newly Created User Is Uniquely Identified. Indicates That the Parameter Is a Bastion Host Corresponding to the User with the Ram User's Unique Identifier. The Newly Created User Source Grant Permission to a RAM User (That Is, Source Used as a Ram), this Parameter Is Required. You Can Call Access Control of Listusers Interface from the Return Data Userid to Obtain the Parameters.
        """
        return pulumi.get(self, "source_user_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The User ID.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> str:
        """
        Specify the New User Name. This Parameter Is Only by Letters, Lowercase Letters, Numbers, and Underscores (_), Supports up to 128 Characters.
        """
        return pulumi.get(self, "user_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDedicatedHostAccountsAccountResult',
    'GetDedicatedHostGroupsGroupResult',
    'GetDedicatedHostGroupsGroupDedicatedHostCountGroupByHostTypeResult',
    'GetDedicatedHostGroupsGroupZoneIdListResult',
    'GetDedicatedHostsHostResult',
    'GetHostEcsLevelInfosInfoResult',
    'GetZonesZoneResult',
]

@pulumi.output_type
class GetDedicatedHostAccountsAccountResult(dict):
    def __init__(__self__, *,
                 account_name: str,
                 dedicated_host_id: str,
                 id: str):
        """
        :param str account_name: The name of the Dedicated host account.
        :param str dedicated_host_id: The ID of the Dedicated host.
        :param str id: The ID of the Dedicated Host Account. The value formats as `<dedicated_host_id>:<account_name>`.
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "dedicated_host_id", dedicated_host_id)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> str:
        """
        The name of the Dedicated host account.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="dedicatedHostId")
    def dedicated_host_id(self) -> str:
        """
        The ID of the Dedicated host.
        """
        return pulumi.get(self, "dedicated_host_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Dedicated Host Account. The value formats as `<dedicated_host_id>:<account_name>`.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class GetDedicatedHostGroupsGroupResult(dict):
    def __init__(__self__, *,
                 allocation_policy: str,
                 bastion_instance_id: str,
                 cpu_allocate_ration: float,
                 cpu_allocated_amount: float,
                 cpu_allocation_ratio: int,
                 create_time: str,
                 dedicated_host_count_group_by_host_types: Sequence['outputs.GetDedicatedHostGroupsGroupDedicatedHostCountGroupByHostTypeResult'],
                 dedicated_host_group_desc: str,
                 dedicated_host_group_id: str,
                 deploy_type: str,
                 disk_allocate_ration: float,
                 disk_allocated_amount: float,
                 disk_allocation_ratio: int,
                 disk_used_amount: float,
                 disk_utility: float,
                 engine: str,
                 host_number: int,
                 host_replace_policy: str,
                 id: str,
                 instance_number: int,
                 mem_allocate_ration: float,
                 mem_allocated_amount: float,
                 mem_allocation_ratio: int,
                 mem_used_amount: float,
                 mem_utility: float,
                 text: str,
                 vpc_id: str,
                 zone_id_lists: Sequence['outputs.GetDedicatedHostGroupsGroupZoneIdListResult']):
        """
        :param str allocation_policy: The policy that is used to allocate resources in the dedicated cluster. Valid values:`Evenly`,`Intensively`
        :param str bastion_instance_id: The Bastion Instance id of the Dedicated Host Group.
        :param float cpu_allocate_ration: The CPU overcommitment ratio of the dedicated cluster. If you set this parameter to 200, the CPU resources that can be allocated are twice as many as the CPU resources that are provided. This maximizes the CPU utilization. Valid values: 100 to 300. Default value: 200.
        :param float cpu_allocated_amount: The CPU Allocated Amount of the Dedicated Host Group.
        :param int cpu_allocation_ratio: The CPU overcommitment ratio of the dedicated cluster.Valid values: 100 to 300. Default value: 200.
        :param str create_time: The Created Time of the Dedicated Host Group.
        :param Sequence['GetDedicatedHostGroupsGroupDedicatedHostCountGroupByHostTypeArgs'] dedicated_host_count_group_by_host_types: The Dedicated Host Count Group by Host Type of the Dedicated Host Group.
        :param str dedicated_host_group_desc: -The name of the dedicated cluster. The name must be 1 to 64 characters in length and can contain letters, digits, underscores (_), and hyphens (-). It must start with a letter.
        :param str dedicated_host_group_id: Dedicated Host Group ID.
        :param str deploy_type: The Deployment Type of the Dedicated Host Group.
        :param float disk_allocate_ration: The storage overcommitment ratio of the dedicated cluster.Valid values: 100 to 300. Default value: 200.
        :param float disk_allocated_amount: The Disk Allocated Amount of the Dedicated Host Group.
        :param int disk_allocation_ratio: The Disk Allocation Ratio of the Dedicated Host Group.
        :param float disk_used_amount: The DiskUsedAmount of the Dedicated Host Group.
        :param float disk_utility: The DiskUtility of the Dedicated Host Group.
        :param str engine: Database Engine Type.The database engine of the dedicated cluster. Valid values:`Redis`, `SQLServer`, `MySQL`, `PostgreSQL`, `MongoDB`
        :param int host_number: The Total Host Number  of the Dedicated Host Group.
        :param str host_replace_policy: The policy based on which the system handles host failures. Valid values:`Auto`,`Manual`
        :param str id: The ID of the Dedicated Host Group.
        :param int instance_number: The Total Instance Number of the Dedicated Host Group.
        :param float mem_allocate_ration: The maximum memory usage of each host in the dedicated cluster.Valid values: 0 to 90. Default value: 90.
        :param float mem_allocated_amount: The MemAllocatedAmount of the Dedicated Host Group.
        :param int mem_allocation_ratio: The Memory Allocation Ratio of the Dedicated Host Group.
        :param float mem_used_amount: The MemUsedAmount of the Dedicated Host Group.
        :param float mem_utility: The Mem Utility of the Dedicated Host Group.
        :param str text: The Text of the Dedicated Host Group.
        :param str vpc_id: The virtual private cloud (VPC) ID of the dedicated cluster.
        :param Sequence['GetDedicatedHostGroupsGroupZoneIdListArgs'] zone_id_lists: The ZoneIDList of the Dedicated Host Group.
        """
        pulumi.set(__self__, "allocation_policy", allocation_policy)
        pulumi.set(__self__, "bastion_instance_id", bastion_instance_id)
        pulumi.set(__self__, "cpu_allocate_ration", cpu_allocate_ration)
        pulumi.set(__self__, "cpu_allocated_amount", cpu_allocated_amount)
        pulumi.set(__self__, "cpu_allocation_ratio", cpu_allocation_ratio)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "dedicated_host_count_group_by_host_types", dedicated_host_count_group_by_host_types)
        pulumi.set(__self__, "dedicated_host_group_desc", dedicated_host_group_desc)
        pulumi.set(__self__, "dedicated_host_group_id", dedicated_host_group_id)
        pulumi.set(__self__, "deploy_type", deploy_type)
        pulumi.set(__self__, "disk_allocate_ration", disk_allocate_ration)
        pulumi.set(__self__, "disk_allocated_amount", disk_allocated_amount)
        pulumi.set(__self__, "disk_allocation_ratio", disk_allocation_ratio)
        pulumi.set(__self__, "disk_used_amount", disk_used_amount)
        pulumi.set(__self__, "disk_utility", disk_utility)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "host_number", host_number)
        pulumi.set(__self__, "host_replace_policy", host_replace_policy)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_number", instance_number)
        pulumi.set(__self__, "mem_allocate_ration", mem_allocate_ration)
        pulumi.set(__self__, "mem_allocated_amount", mem_allocated_amount)
        pulumi.set(__self__, "mem_allocation_ratio", mem_allocation_ratio)
        pulumi.set(__self__, "mem_used_amount", mem_used_amount)
        pulumi.set(__self__, "mem_utility", mem_utility)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id_lists", zone_id_lists)

    @property
    @pulumi.getter(name="allocationPolicy")
    def allocation_policy(self) -> str:
        """
        The policy that is used to allocate resources in the dedicated cluster. Valid values:`Evenly`,`Intensively`
        """
        return pulumi.get(self, "allocation_policy")

    @property
    @pulumi.getter(name="bastionInstanceId")
    def bastion_instance_id(self) -> str:
        """
        The Bastion Instance id of the Dedicated Host Group.
        """
        return pulumi.get(self, "bastion_instance_id")

    @property
    @pulumi.getter(name="cpuAllocateRation")
    def cpu_allocate_ration(self) -> float:
        """
        The CPU overcommitment ratio of the dedicated cluster. If you set this parameter to 200, the CPU resources that can be allocated are twice as many as the CPU resources that are provided. This maximizes the CPU utilization. Valid values: 100 to 300. Default value: 200.
        """
        return pulumi.get(self, "cpu_allocate_ration")

    @property
    @pulumi.getter(name="cpuAllocatedAmount")
    def cpu_allocated_amount(self) -> float:
        """
        The CPU Allocated Amount of the Dedicated Host Group.
        """
        return pulumi.get(self, "cpu_allocated_amount")

    @property
    @pulumi.getter(name="cpuAllocationRatio")
    def cpu_allocation_ratio(self) -> int:
        """
        The CPU overcommitment ratio of the dedicated cluster.Valid values: 100 to 300. Default value: 200.
        """
        return pulumi.get(self, "cpu_allocation_ratio")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The Created Time of the Dedicated Host Group.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dedicatedHostCountGroupByHostTypes")
    def dedicated_host_count_group_by_host_types(self) -> Sequence['outputs.GetDedicatedHostGroupsGroupDedicatedHostCountGroupByHostTypeResult']:
        """
        The Dedicated Host Count Group by Host Type of the Dedicated Host Group.
        """
        return pulumi.get(self, "dedicated_host_count_group_by_host_types")

    @property
    @pulumi.getter(name="dedicatedHostGroupDesc")
    def dedicated_host_group_desc(self) -> str:
        """
        -The name of the dedicated cluster. The name must be 1 to 64 characters in length and can contain letters, digits, underscores (_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "dedicated_host_group_desc")

    @property
    @pulumi.getter(name="dedicatedHostGroupId")
    def dedicated_host_group_id(self) -> str:
        """
        Dedicated Host Group ID.
        """
        return pulumi.get(self, "dedicated_host_group_id")

    @property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> str:
        """
        The Deployment Type of the Dedicated Host Group.
        """
        return pulumi.get(self, "deploy_type")

    @property
    @pulumi.getter(name="diskAllocateRation")
    def disk_allocate_ration(self) -> float:
        """
        The storage overcommitment ratio of the dedicated cluster.Valid values: 100 to 300. Default value: 200.
        """
        return pulumi.get(self, "disk_allocate_ration")

    @property
    @pulumi.getter(name="diskAllocatedAmount")
    def disk_allocated_amount(self) -> float:
        """
        The Disk Allocated Amount of the Dedicated Host Group.
        """
        return pulumi.get(self, "disk_allocated_amount")

    @property
    @pulumi.getter(name="diskAllocationRatio")
    def disk_allocation_ratio(self) -> int:
        """
        The Disk Allocation Ratio of the Dedicated Host Group.
        """
        return pulumi.get(self, "disk_allocation_ratio")

    @property
    @pulumi.getter(name="diskUsedAmount")
    def disk_used_amount(self) -> float:
        """
        The DiskUsedAmount of the Dedicated Host Group.
        """
        return pulumi.get(self, "disk_used_amount")

    @property
    @pulumi.getter(name="diskUtility")
    def disk_utility(self) -> float:
        """
        The DiskUtility of the Dedicated Host Group.
        """
        return pulumi.get(self, "disk_utility")

    @property
    @pulumi.getter
    def engine(self) -> str:
        """
        Database Engine Type.The database engine of the dedicated cluster. Valid values:`Redis`, `SQLServer`, `MySQL`, `PostgreSQL`, `MongoDB`
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="hostNumber")
    def host_number(self) -> int:
        """
        The Total Host Number  of the Dedicated Host Group.
        """
        return pulumi.get(self, "host_number")

    @property
    @pulumi.getter(name="hostReplacePolicy")
    def host_replace_policy(self) -> str:
        """
        The policy based on which the system handles host failures. Valid values:`Auto`,`Manual`
        """
        return pulumi.get(self, "host_replace_policy")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Dedicated Host Group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceNumber")
    def instance_number(self) -> int:
        """
        The Total Instance Number of the Dedicated Host Group.
        """
        return pulumi.get(self, "instance_number")

    @property
    @pulumi.getter(name="memAllocateRation")
    def mem_allocate_ration(self) -> float:
        """
        The maximum memory usage of each host in the dedicated cluster.Valid values: 0 to 90. Default value: 90.
        """
        return pulumi.get(self, "mem_allocate_ration")

    @property
    @pulumi.getter(name="memAllocatedAmount")
    def mem_allocated_amount(self) -> float:
        """
        The MemAllocatedAmount of the Dedicated Host Group.
        """
        return pulumi.get(self, "mem_allocated_amount")

    @property
    @pulumi.getter(name="memAllocationRatio")
    def mem_allocation_ratio(self) -> int:
        """
        The Memory Allocation Ratio of the Dedicated Host Group.
        """
        return pulumi.get(self, "mem_allocation_ratio")

    @property
    @pulumi.getter(name="memUsedAmount")
    def mem_used_amount(self) -> float:
        """
        The MemUsedAmount of the Dedicated Host Group.
        """
        return pulumi.get(self, "mem_used_amount")

    @property
    @pulumi.getter(name="memUtility")
    def mem_utility(self) -> float:
        """
        The Mem Utility of the Dedicated Host Group.
        """
        return pulumi.get(self, "mem_utility")

    @property
    @pulumi.getter
    def text(self) -> str:
        """
        The Text of the Dedicated Host Group.
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The virtual private cloud (VPC) ID of the dedicated cluster.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> Sequence['outputs.GetDedicatedHostGroupsGroupZoneIdListResult']:
        """
        The ZoneIDList of the Dedicated Host Group.
        """
        return pulumi.get(self, "zone_id_lists")


@pulumi.output_type
class GetDedicatedHostGroupsGroupDedicatedHostCountGroupByHostTypeResult(dict):
    def __init__(__self__, *,
                 place_holder: str):
        pulumi.set(__self__, "place_holder", place_holder)

    @property
    @pulumi.getter(name="placeHolder")
    def place_holder(self) -> str:
        return pulumi.get(self, "place_holder")


@pulumi.output_type
class GetDedicatedHostGroupsGroupZoneIdListResult(dict):
    def __init__(__self__, *,
                 zone_id_lists: Sequence[str]):
        """
        :param Sequence[str] zone_id_lists: The ZoneIDList of the Dedicated Host Group.
        """
        pulumi.set(__self__, "zone_id_lists", zone_id_lists)

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> Sequence[str]:
        """
        The ZoneIDList of the Dedicated Host Group.
        """
        return pulumi.get(self, "zone_id_lists")


@pulumi.output_type
class GetDedicatedHostsHostResult(dict):
    def __init__(__self__, *,
                 allocation_status: str,
                 bastion_instance_id: str,
                 cpu_allocation_ratio: str,
                 cpu_used: str,
                 create_time: str,
                 dedicated_host_group_id: str,
                 dedicated_host_id: str,
                 disk_allocation_ratio: str,
                 ecs_class_code: str,
                 end_time: str,
                 engine: str,
                 expired_time: str,
                 host_class: str,
                 host_cpu: str,
                 host_mem: str,
                 host_name: str,
                 host_storage: str,
                 host_type: str,
                 id: str,
                 image_category: str,
                 ip_address: str,
                 mem_allocation_ratio: str,
                 memory_used: str,
                 open_permission: str,
                 status: str,
                 storage_used: str,
                 tags: Mapping[str, Any],
                 vpc_id: str,
                 vswitch_id: str,
                 zone_id: str):
        """
        :param str allocation_status: Specifies whether instances can be created on the host. Valid values: `1` or `0`. `1`: Instances can be created on the host. `0`: Instances cannot be created on the host.
        :param str bastion_instance_id: The ID of the bastion host with which the host is associated.
        :param str cpu_allocation_ratio: The numeric value of the CPU over commit ratio of the dedicated cluster.
        :param str cpu_used: The number of CPU cores used by the host.
        :param str create_time: The time when the host was created. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        :param str dedicated_host_group_id: The ID of the dedicated cluster in which the host is created.
        :param str dedicated_host_id: The ID of the host.
        :param str disk_allocation_ratio: The disk usage in percentage.
        :param str ecs_class_code: The Elastic Compute Service (ECS) instance type.
        :param str end_time: The time when the host expires. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        :param str engine: The type of the database engine that is used by the host.
        :param str expired_time: The time when the host expires. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        :param str host_class: The instance type of the host.
        :param str host_cpu: The number of CPU cores specified for the host. Unit: `core`.
        :param str host_mem: The memory of the host. Unit: `GB`.
        :param str host_name: The name of the host.
        :param str host_storage: The total storage capacity of the host. Unit: `GB`.
        :param str host_type: The storage type of the host.
        :param str id: The ID of the Dedicated Host. The value formats as `<dedicated_host_group_id>:<dedicated_host_id>`.
        :param str image_category: The image type of the host.
        :param str ip_address: The IP address of the host.
        :param str mem_allocation_ratio: The memory usage in percentage.
        :param str memory_used: The amount of memory used by the host. Unit: `GB`.
        :param str open_permission: Indicates whether you have the OS permissions on the host. Valid values: `0`: You do not have the OS permissions on the host. `1`: You have the OS permissions on the host.
        :param str status: The state of the host.
        :param str storage_used: The storage usage of the host. Unit: `GB`.
        :param Mapping[str, Any] tags: The tag of the resource.
        :param str vpc_id: The ID of the virtual private cloud (VPC) to which the host is connected.
        :param str vswitch_id: The ID of the vSwitch.
        :param str zone_id: The zone ID of the host.
        """
        pulumi.set(__self__, "allocation_status", allocation_status)
        pulumi.set(__self__, "bastion_instance_id", bastion_instance_id)
        pulumi.set(__self__, "cpu_allocation_ratio", cpu_allocation_ratio)
        pulumi.set(__self__, "cpu_used", cpu_used)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "dedicated_host_group_id", dedicated_host_group_id)
        pulumi.set(__self__, "dedicated_host_id", dedicated_host_id)
        pulumi.set(__self__, "disk_allocation_ratio", disk_allocation_ratio)
        pulumi.set(__self__, "ecs_class_code", ecs_class_code)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "expired_time", expired_time)
        pulumi.set(__self__, "host_class", host_class)
        pulumi.set(__self__, "host_cpu", host_cpu)
        pulumi.set(__self__, "host_mem", host_mem)
        pulumi.set(__self__, "host_name", host_name)
        pulumi.set(__self__, "host_storage", host_storage)
        pulumi.set(__self__, "host_type", host_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "image_category", image_category)
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "mem_allocation_ratio", mem_allocation_ratio)
        pulumi.set(__self__, "memory_used", memory_used)
        pulumi.set(__self__, "open_permission", open_permission)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "storage_used", storage_used)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="allocationStatus")
    def allocation_status(self) -> str:
        """
        Specifies whether instances can be created on the host. Valid values: `1` or `0`. `1`: Instances can be created on the host. `0`: Instances cannot be created on the host.
        """
        return pulumi.get(self, "allocation_status")

    @property
    @pulumi.getter(name="bastionInstanceId")
    def bastion_instance_id(self) -> str:
        """
        The ID of the bastion host with which the host is associated.
        """
        return pulumi.get(self, "bastion_instance_id")

    @property
    @pulumi.getter(name="cpuAllocationRatio")
    def cpu_allocation_ratio(self) -> str:
        """
        The numeric value of the CPU over commit ratio of the dedicated cluster.
        """
        return pulumi.get(self, "cpu_allocation_ratio")

    @property
    @pulumi.getter(name="cpuUsed")
    def cpu_used(self) -> str:
        """
        The number of CPU cores used by the host.
        """
        return pulumi.get(self, "cpu_used")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The time when the host was created. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dedicatedHostGroupId")
    def dedicated_host_group_id(self) -> str:
        """
        The ID of the dedicated cluster in which the host is created.
        """
        return pulumi.get(self, "dedicated_host_group_id")

    @property
    @pulumi.getter(name="dedicatedHostId")
    def dedicated_host_id(self) -> str:
        """
        The ID of the host.
        """
        return pulumi.get(self, "dedicated_host_id")

    @property
    @pulumi.getter(name="diskAllocationRatio")
    def disk_allocation_ratio(self) -> str:
        """
        The disk usage in percentage.
        """
        return pulumi.get(self, "disk_allocation_ratio")

    @property
    @pulumi.getter(name="ecsClassCode")
    def ecs_class_code(self) -> str:
        """
        The Elastic Compute Service (ECS) instance type.
        """
        return pulumi.get(self, "ecs_class_code")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> str:
        """
        The time when the host expires. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter
    def engine(self) -> str:
        """
        The type of the database engine that is used by the host.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> str:
        """
        The time when the host expires. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="hostClass")
    def host_class(self) -> str:
        """
        The instance type of the host.
        """
        return pulumi.get(self, "host_class")

    @property
    @pulumi.getter(name="hostCpu")
    def host_cpu(self) -> str:
        """
        The number of CPU cores specified for the host. Unit: `core`.
        """
        return pulumi.get(self, "host_cpu")

    @property
    @pulumi.getter(name="hostMem")
    def host_mem(self) -> str:
        """
        The memory of the host. Unit: `GB`.
        """
        return pulumi.get(self, "host_mem")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> str:
        """
        The name of the host.
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hostStorage")
    def host_storage(self) -> str:
        """
        The total storage capacity of the host. Unit: `GB`.
        """
        return pulumi.get(self, "host_storage")

    @property
    @pulumi.getter(name="hostType")
    def host_type(self) -> str:
        """
        The storage type of the host.
        """
        return pulumi.get(self, "host_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Dedicated Host. The value formats as `<dedicated_host_group_id>:<dedicated_host_id>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageCategory")
    def image_category(self) -> str:
        """
        The image type of the host.
        """
        return pulumi.get(self, "image_category")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        The IP address of the host.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="memAllocationRatio")
    def mem_allocation_ratio(self) -> str:
        """
        The memory usage in percentage.
        """
        return pulumi.get(self, "mem_allocation_ratio")

    @property
    @pulumi.getter(name="memoryUsed")
    def memory_used(self) -> str:
        """
        The amount of memory used by the host. Unit: `GB`.
        """
        return pulumi.get(self, "memory_used")

    @property
    @pulumi.getter(name="openPermission")
    def open_permission(self) -> str:
        """
        Indicates whether you have the OS permissions on the host. Valid values: `0`: You do not have the OS permissions on the host. `1`: You have the OS permissions on the host.
        """
        return pulumi.get(self, "open_permission")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The state of the host.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageUsed")
    def storage_used(self) -> str:
        """
        The storage usage of the host. Unit: `GB`.
        """
        return pulumi.get(self, "storage_used")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of the virtual private cloud (VPC) to which the host is connected.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> str:
        """
        The ID of the vSwitch.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The zone ID of the host.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetHostEcsLevelInfosInfoResult(dict):
    def __init__(__self__, *,
                 description: str,
                 ecs_class: str,
                 ecs_class_code: str,
                 res_class_code: str):
        """
        :param str description: The description of the host ecs level info.
        :param str ecs_class: The instance family of the host ecs level info.
        :param str ecs_class_code: The Elastic Compute Service (ECS) instance type.
        :param str res_class_code: The ApsaraDB RDS instance type of the host ecs level info.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "ecs_class", ecs_class)
        pulumi.set(__self__, "ecs_class_code", ecs_class_code)
        pulumi.set(__self__, "res_class_code", res_class_code)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the host ecs level info.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ecsClass")
    def ecs_class(self) -> str:
        """
        The instance family of the host ecs level info.
        """
        return pulumi.get(self, "ecs_class")

    @property
    @pulumi.getter(name="ecsClassCode")
    def ecs_class_code(self) -> str:
        """
        The Elastic Compute Service (ECS) instance type.
        """
        return pulumi.get(self, "ecs_class_code")

    @property
    @pulumi.getter(name="resClassCode")
    def res_class_code(self) -> str:
        """
        The ApsaraDB RDS instance type of the host ecs level info.
        """
        return pulumi.get(self, "res_class_code")


@pulumi.output_type
class GetZonesZoneResult(dict):
    def __init__(__self__, *,
                 id: str,
                 region_id: str,
                 zone_id: str):
        """
        :param str id: The ID of the zone.
        :param str region_id: The ID of the region.
        :param str zone_id: The ID of the zone.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "region_id", region_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the zone.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        """
        The ID of the region.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The ID of the zone.
        """
        return pulumi.get(self, "zone_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .application_load_balancer import *
from .attachment import *
from .backend_server import *
from .ca_certificate import *
from .domain_extension import *
from .get_acls import *
from .get_application_load_balancers import *
from .get_attachments import *
from .get_backend_servers import *
from .get_ca_certificates import *
from .get_domain_extensions import *
from .get_listeners import *
from .get_load_balancers import *
from .get_master_slave_server_groups import *
from .get_rules import *
from .get_server_certificates import *
from .get_server_groups import *
from .get_tls_cipher_policies import *
from .get_zones import *
from .listener import *
from .load_balancer import *
from .master_slave_server_group import *
from .rule import *
from .server_certificate import *
from .server_group import *
from .tls_cipher_policy import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetApplicationGroupsGroupResult',
    'GetApplicationsApplicationResult',
    'GetExecutionsExecutionResult',
    'GetParametersParameterResult',
    'GetPatchBaselinesBaselineResult',
    'GetSecretParametersParameterResult',
    'GetStateConfigurationsConfigurationResult',
    'GetTemplatesTemplateResult',
]

@pulumi.output_type
class GetApplicationGroupsGroupResult(dict):
    def __init__(__self__, *,
                 application_group_name: str,
                 application_name: str,
                 cms_group_id: str,
                 create_time: str,
                 deploy_region_id: str,
                 description: str,
                 id: str,
                 import_tag_key: str,
                 import_tag_value: str,
                 update_time: str):
        """
        :param str application_group_name: The name of the Application group.
        :param str application_name: The name of the Application.
        :param str cms_group_id: The ID of the cloud monitor group.
        :param str create_time: The Creation time of the resource.
        :param str deploy_region_id: The region ID of the deployment.
        :param str description: Application group description information.
        :param str id: The ID of the Application Group. Its value is same as Queue Name.
        :param str import_tag_key: Label key.
        :param str import_tag_value: Label value.
        :param str update_time: The Update time of the resource.
        """
        pulumi.set(__self__, "application_group_name", application_group_name)
        pulumi.set(__self__, "application_name", application_name)
        pulumi.set(__self__, "cms_group_id", cms_group_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "deploy_region_id", deploy_region_id)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "import_tag_key", import_tag_key)
        pulumi.set(__self__, "import_tag_value", import_tag_value)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="applicationGroupName")
    def application_group_name(self) -> str:
        """
        The name of the Application group.
        """
        return pulumi.get(self, "application_group_name")

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> str:
        """
        The name of the Application.
        """
        return pulumi.get(self, "application_name")

    @property
    @pulumi.getter(name="cmsGroupId")
    def cms_group_id(self) -> str:
        """
        The ID of the cloud monitor group.
        """
        return pulumi.get(self, "cms_group_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The Creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deployRegionId")
    def deploy_region_id(self) -> str:
        """
        The region ID of the deployment.
        """
        return pulumi.get(self, "deploy_region_id")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Application group description information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Application Group. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="importTagKey")
    def import_tag_key(self) -> str:
        """
        Label key.
        """
        return pulumi.get(self, "import_tag_key")

    @property
    @pulumi.getter(name="importTagValue")
    def import_tag_value(self) -> str:
        """
        Label value.
        """
        return pulumi.get(self, "import_tag_value")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> str:
        """
        The Update time of the resource.
        """
        return pulumi.get(self, "update_time")


@pulumi.output_type
class GetApplicationsApplicationResult(dict):
    def __init__(__self__, *,
                 application_name: str,
                 create_time: str,
                 description: str,
                 id: str,
                 resource_group_id: str,
                 tags: Mapping[str, Any],
                 update_time: str):
        """
        :param str application_name: The name of the application.
        :param str create_time: The Created time of the application.
        :param str description: Application group description information.
        :param str id: The ID of the Application. The value is formate as <application_name>.
        :param str resource_group_id: The ID of the resource group.
        :param Mapping[str, Any] tags: The tag of the resource.
        :param str update_time: The Updated time of the application.
        """
        pulumi.set(__self__, "application_name", application_name)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> str:
        """
        The name of the application.
        """
        return pulumi.get(self, "application_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The Created time of the application.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Application group description information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Application. The value is formate as <application_name>.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> str:
        """
        The Updated time of the application.
        """
        return pulumi.get(self, "update_time")


@pulumi.output_type
class GetExecutionsExecutionResult(dict):
    def __init__(__self__, *,
                 category: str,
                 counters: str,
                 create_date: str,
                 end_date: str,
                 executed_by: str,
                 execution_id: str,
                 id: str,
                 is_parent: bool,
                 mode: str,
                 outputs: str,
                 parameters: str,
                 parent_execution_id: str,
                 ram_role: str,
                 start_date: str,
                 status: str,
                 status_message: str,
                 status_reason: str,
                 template_id: str,
                 template_name: str,
                 template_version: str,
                 update_date: str):
        """
        :param str category: The category of template. Valid: `AlarmTrigger`, `EventTrigger`, `Other` and `TimerTrigger`.
        :param str counters: The counters of OOS Execution.
        :param str create_date: The time when the execution was created.
        :param str end_date: The time when the execution was ended.
        :param str executed_by: The user who execute the template.
        :param str execution_id: ID of the OOS Executions.
        :param str id: ID of the OOS Executions.
        :param bool is_parent: Whether to include subtasks.
        :param str mode: The mode of OOS Execution. Valid: `Automatic`, `Debug`.
        :param str outputs: The outputs of OOS Executions.
        :param str parameters: The parameters required by the template
        :param str parent_execution_id: The id of parent OOS Execution.
        :param str ram_role: The role that executes the current template.
        :param str start_date: The time when the template was started.
        :param str status: The Status of OOS Execution. Valid: `Cancelled`, `Failed`, `Queued`, `Running`, `Started`, `Success`, `Waiting`.
        :param str status_message: The message of status.
        :param str status_reason: The reason of status.
        :param str template_id: The id of execution template.
        :param str template_name: The name of execution template.
        :param str template_version: The version of execution template.
        :param str update_date: The time when the template was updated.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "counters", counters)
        pulumi.set(__self__, "create_date", create_date)
        pulumi.set(__self__, "end_date", end_date)
        pulumi.set(__self__, "executed_by", executed_by)
        pulumi.set(__self__, "execution_id", execution_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_parent", is_parent)
        pulumi.set(__self__, "mode", mode)
        pulumi.set(__self__, "outputs", outputs)
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "parent_execution_id", parent_execution_id)
        pulumi.set(__self__, "ram_role", ram_role)
        pulumi.set(__self__, "start_date", start_date)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "status_message", status_message)
        pulumi.set(__self__, "status_reason", status_reason)
        pulumi.set(__self__, "template_id", template_id)
        pulumi.set(__self__, "template_name", template_name)
        pulumi.set(__self__, "template_version", template_version)
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter
    def category(self) -> str:
        """
        The category of template. Valid: `AlarmTrigger`, `EventTrigger`, `Other` and `TimerTrigger`.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter
    def counters(self) -> str:
        """
        The counters of OOS Execution.
        """
        return pulumi.get(self, "counters")

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> str:
        """
        The time when the execution was created.
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> str:
        """
        The time when the execution was ended.
        """
        return pulumi.get(self, "end_date")

    @property
    @pulumi.getter(name="executedBy")
    def executed_by(self) -> str:
        """
        The user who execute the template.
        """
        return pulumi.get(self, "executed_by")

    @property
    @pulumi.getter(name="executionId")
    def execution_id(self) -> str:
        """
        ID of the OOS Executions.
        """
        return pulumi.get(self, "execution_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the OOS Executions.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isParent")
    def is_parent(self) -> bool:
        """
        Whether to include subtasks.
        """
        return pulumi.get(self, "is_parent")

    @property
    @pulumi.getter
    def mode(self) -> str:
        """
        The mode of OOS Execution. Valid: `Automatic`, `Debug`.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def outputs(self) -> str:
        """
        The outputs of OOS Executions.
        """
        return pulumi.get(self, "outputs")

    @property
    @pulumi.getter
    def parameters(self) -> str:
        """
        The parameters required by the template
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="parentExecutionId")
    def parent_execution_id(self) -> str:
        """
        The id of parent OOS Execution.
        """
        return pulumi.get(self, "parent_execution_id")

    @property
    @pulumi.getter(name="ramRole")
    def ram_role(self) -> str:
        """
        The role that executes the current template.
        """
        return pulumi.get(self, "ram_role")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> str:
        """
        The time when the template was started.
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The Status of OOS Execution. Valid: `Cancelled`, `Failed`, `Queued`, `Running`, `Started`, `Success`, `Waiting`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> str:
        """
        The message of status.
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter(name="statusReason")
    def status_reason(self) -> str:
        """
        The reason of status.
        """
        return pulumi.get(self, "status_reason")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> str:
        """
        The id of execution template.
        """
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> str:
        """
        The name of execution template.
        """
        return pulumi.get(self, "template_name")

    @property
    @pulumi.getter(name="templateVersion")
    def template_version(self) -> str:
        """
        The version of execution template.
        """
        return pulumi.get(self, "template_version")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> str:
        """
        The time when the template was updated.
        """
        return pulumi.get(self, "update_date")


@pulumi.output_type
class GetParametersParameterResult(dict):
    def __init__(__self__, *,
                 constraints: str,
                 create_time: str,
                 created_by: str,
                 description: str,
                 id: str,
                 parameter_id: str,
                 parameter_name: str,
                 parameter_version: int,
                 resource_group_id: str,
                 share_type: str,
                 tags: Mapping[str, Any],
                 type: str,
                 updated_by: str,
                 updated_date: str,
                 value: str):
        """
        :param str constraints: The constraints of the common parameter.
        :param str create_time: The time when the common parameter was created.
        :param str created_by: The user who created the common parameter.
        :param str description: The description of the common parameter.
        :param str id: The ID of the Parameter. Its value is same as `parameter_name`.
        :param str parameter_id: The ID of the common parameter.
        :param str parameter_name: The name of the common parameter.
        :param int parameter_version: The version number of the common parameter.
        :param str resource_group_id: The ID of the Resource Group.
        :param str share_type: The share type of the common parameter.
        :param Mapping[str, Any] tags: The tag of the resource.
        :param str type: The data type of the common parameter.
        :param str updated_by: The user who updated the common parameter.
        :param str updated_date: The time when the common parameter was updated.
        :param str value: The value of the common parameter.
        """
        pulumi.set(__self__, "constraints", constraints)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "created_by", created_by)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "parameter_id", parameter_id)
        pulumi.set(__self__, "parameter_name", parameter_name)
        pulumi.set(__self__, "parameter_version", parameter_version)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "share_type", share_type)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "updated_by", updated_by)
        pulumi.set(__self__, "updated_date", updated_date)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def constraints(self) -> str:
        """
        The constraints of the common parameter.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The time when the common parameter was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user who created the common parameter.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the common parameter.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Parameter. Its value is same as `parameter_name`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="parameterId")
    def parameter_id(self) -> str:
        """
        The ID of the common parameter.
        """
        return pulumi.get(self, "parameter_id")

    @property
    @pulumi.getter(name="parameterName")
    def parameter_name(self) -> str:
        """
        The name of the common parameter.
        """
        return pulumi.get(self, "parameter_name")

    @property
    @pulumi.getter(name="parameterVersion")
    def parameter_version(self) -> int:
        """
        The version number of the common parameter.
        """
        return pulumi.get(self, "parameter_version")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        The ID of the Resource Group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="shareType")
    def share_type(self) -> str:
        """
        The share type of the common parameter.
        """
        return pulumi.get(self, "share_type")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The data type of the common parameter.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> str:
        """
        The user who updated the common parameter.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter(name="updatedDate")
    def updated_date(self) -> str:
        """
        The time when the common parameter was updated.
        """
        return pulumi.get(self, "updated_date")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value of the common parameter.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetPatchBaselinesBaselineResult(dict):
    def __init__(__self__, *,
                 approval_rules: str,
                 create_time: str,
                 created_by: str,
                 description: str,
                 id: str,
                 is_default: bool,
                 operation_system: str,
                 patch_baseline_id: str,
                 patch_baseline_name: str,
                 share_type: str,
                 updated_by: str,
                 updated_date: str):
        """
        :param str approval_rules: Accept the rules.
        :param str create_time: The create time of patch baselines.
        :param str created_by: The user who created the patch baselines.
        :param str description: Patches baseline description information.
        :param str id: The ID of the Patch Baseline. Its value is same as `patch_baseline_name`.
        :param bool is_default: Whether it is the default patch baseline.
        :param str operation_system: Operating system type.
        :param str patch_baseline_id: Patch baseline ID.
        :param str patch_baseline_name: The name of the patch baseline.
        :param str share_type: Patch baseline sharing type.
        :param str updated_by: The user who updated the patch baselines.
        :param str updated_date: The update time of patch baselines.
        """
        pulumi.set(__self__, "approval_rules", approval_rules)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "created_by", created_by)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_default", is_default)
        pulumi.set(__self__, "operation_system", operation_system)
        pulumi.set(__self__, "patch_baseline_id", patch_baseline_id)
        pulumi.set(__self__, "patch_baseline_name", patch_baseline_name)
        pulumi.set(__self__, "share_type", share_type)
        pulumi.set(__self__, "updated_by", updated_by)
        pulumi.set(__self__, "updated_date", updated_date)

    @property
    @pulumi.getter(name="approvalRules")
    def approval_rules(self) -> str:
        """
        Accept the rules.
        """
        return pulumi.get(self, "approval_rules")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The create time of patch baselines.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user who created the patch baselines.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Patches baseline description information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Patch Baseline. Its value is same as `patch_baseline_name`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> bool:
        """
        Whether it is the default patch baseline.
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="operationSystem")
    def operation_system(self) -> str:
        """
        Operating system type.
        """
        return pulumi.get(self, "operation_system")

    @property
    @pulumi.getter(name="patchBaselineId")
    def patch_baseline_id(self) -> str:
        """
        Patch baseline ID.
        """
        return pulumi.get(self, "patch_baseline_id")

    @property
    @pulumi.getter(name="patchBaselineName")
    def patch_baseline_name(self) -> str:
        """
        The name of the patch baseline.
        """
        return pulumi.get(self, "patch_baseline_name")

    @property
    @pulumi.getter(name="shareType")
    def share_type(self) -> str:
        """
        Patch baseline sharing type.
        """
        return pulumi.get(self, "share_type")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> str:
        """
        The user who updated the patch baselines.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter(name="updatedDate")
    def updated_date(self) -> str:
        """
        The update time of patch baselines.
        """
        return pulumi.get(self, "updated_date")


@pulumi.output_type
class GetSecretParametersParameterResult(dict):
    def __init__(__self__, *,
                 constraints: str,
                 create_time: str,
                 created_by: str,
                 description: str,
                 id: str,
                 key_id: str,
                 parameter_version: int,
                 resource_group_id: str,
                 secret_parameter_id: str,
                 secret_parameter_name: str,
                 share_type: str,
                 tags: Mapping[str, Any],
                 type: str,
                 updated_by: str,
                 updated_date: str):
        """
        :param str constraints: The constraints of the encryption parameter.
        :param str create_time: The time when the encryption parameter was created.
        :param str created_by: The user who created the encryption parameter.
        :param str description: The description of the encryption parameter.
        :param str id: The ID of the Secret Parameter.
        :param str key_id: KeyId of KMS used for encryption.
        :param int parameter_version: The version number of the encryption parameter.
        :param str resource_group_id: The ID of the Resource Group.
        :param str secret_parameter_id: The ID of the encryption parameter.
        :param str secret_parameter_name: The name of the encryption parameter.
        :param str share_type: The share type of the encryption parameter.
        :param Mapping[str, Any] tags: The tag of the resource.
        :param str type: The data type of the encryption parameter.
        :param str updated_by: The user who updated the encryption parameter.
        :param str updated_date: The time when the encryption parameter was updated.
        """
        pulumi.set(__self__, "constraints", constraints)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "created_by", created_by)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "key_id", key_id)
        pulumi.set(__self__, "parameter_version", parameter_version)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "secret_parameter_id", secret_parameter_id)
        pulumi.set(__self__, "secret_parameter_name", secret_parameter_name)
        pulumi.set(__self__, "share_type", share_type)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "updated_by", updated_by)
        pulumi.set(__self__, "updated_date", updated_date)

    @property
    @pulumi.getter
    def constraints(self) -> str:
        """
        The constraints of the encryption parameter.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The time when the encryption parameter was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user who created the encryption parameter.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the encryption parameter.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Secret Parameter.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> str:
        """
        KeyId of KMS used for encryption.
        """
        return pulumi.get(self, "key_id")

    @property
    @pulumi.getter(name="parameterVersion")
    def parameter_version(self) -> int:
        """
        The version number of the encryption parameter.
        """
        return pulumi.get(self, "parameter_version")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        The ID of the Resource Group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="secretParameterId")
    def secret_parameter_id(self) -> str:
        """
        The ID of the encryption parameter.
        """
        return pulumi.get(self, "secret_parameter_id")

    @property
    @pulumi.getter(name="secretParameterName")
    def secret_parameter_name(self) -> str:
        """
        The name of the encryption parameter.
        """
        return pulumi.get(self, "secret_parameter_name")

    @property
    @pulumi.getter(name="shareType")
    def share_type(self) -> str:
        """
        The share type of the encryption parameter.
        """
        return pulumi.get(self, "share_type")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The data type of the encryption parameter.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> str:
        """
        The user who updated the encryption parameter.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter(name="updatedDate")
    def updated_date(self) -> str:
        """
        The time when the encryption parameter was updated.
        """
        return pulumi.get(self, "updated_date")


@pulumi.output_type
class GetStateConfigurationsConfigurationResult(dict):
    def __init__(__self__, *,
                 configure_mode: str,
                 create_time: str,
                 description: str,
                 id: str,
                 parameters: str,
                 resource_group_id: str,
                 schedule_expression: str,
                 schedule_type: str,
                 state_configuration_id: str,
                 tags: Mapping[str, Any],
                 targets: str,
                 template_id: str,
                 template_name: str,
                 template_version: str,
                 update_time: str):
        """
        :param str configure_mode: The configuration mode.
        :param str create_time: The creation time.
        :param str description: The description.
        :param str id: The ID of the State Configuration.
        :param str parameters: The parameters.
        :param str resource_group_id: The ID of the resource group.
        :param str schedule_expression: The schedule expression.
        :param str schedule_type: The schedule type.
        :param str state_configuration_id: The ID of the final state configuration.
        :param Mapping[str, Any] tags: The tag of the resource.
        :param str targets: The target resource.
        :param str template_id: The ID of the template.
        :param str template_name: The name of the template.
        :param str template_version: The version of the template.
        :param str update_time: The time when the configuration is updated.
        """
        pulumi.set(__self__, "configure_mode", configure_mode)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "schedule_expression", schedule_expression)
        pulumi.set(__self__, "schedule_type", schedule_type)
        pulumi.set(__self__, "state_configuration_id", state_configuration_id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "targets", targets)
        pulumi.set(__self__, "template_id", template_id)
        pulumi.set(__self__, "template_name", template_name)
        pulumi.set(__self__, "template_version", template_version)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="configureMode")
    def configure_mode(self) -> str:
        """
        The configuration mode.
        """
        return pulumi.get(self, "configure_mode")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the State Configuration.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def parameters(self) -> str:
        """
        The parameters.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="scheduleExpression")
    def schedule_expression(self) -> str:
        """
        The schedule expression.
        """
        return pulumi.get(self, "schedule_expression")

    @property
    @pulumi.getter(name="scheduleType")
    def schedule_type(self) -> str:
        """
        The schedule type.
        """
        return pulumi.get(self, "schedule_type")

    @property
    @pulumi.getter(name="stateConfigurationId")
    def state_configuration_id(self) -> str:
        """
        The ID of the final state configuration.
        """
        return pulumi.get(self, "state_configuration_id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def targets(self) -> str:
        """
        The target resource.
        """
        return pulumi.get(self, "targets")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> str:
        """
        The ID of the template.
        """
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> str:
        """
        The name of the template.
        """
        return pulumi.get(self, "template_name")

    @property
    @pulumi.getter(name="templateVersion")
    def template_version(self) -> str:
        """
        The version of the template.
        """
        return pulumi.get(self, "template_version")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> str:
        """
        The time when the configuration is updated.
        """
        return pulumi.get(self, "update_time")


@pulumi.output_type
class GetTemplatesTemplateResult(dict):
    def __init__(__self__, *,
                 category: str,
                 created_by: str,
                 created_date: str,
                 description: str,
                 has_trigger: bool,
                 id: str,
                 share_type: str,
                 tags: Mapping[str, Any],
                 template_format: str,
                 template_id: str,
                 template_name: str,
                 template_type: str,
                 template_version: str,
                 updated_by: str,
                 updated_date: str):
        """
        :param str category: The category of template.
        :param str created_by: The creator of the template.
        :param str created_date: The template whose creation time is less than or equal to the specified time. The format is: YYYY-MM-DDThh:mm::ssZ.
        :param str description: Description of the OOS Template.
        :param bool has_trigger: Is it triggered successfully.
        :param str id: ID of the OOS Template. The value is same as template_name.
        :param str share_type: The sharing type of the template. Valid values: `Private`, `Public`.
        :param Mapping[str, Any] tags: A mapping of tags to assign to the resource.
        :param str template_format: The format of the template. Valid values: `JSON`, `YAML`.
        :param str template_id: ID of the OOS Template resource.
        :param str template_name: Name of the OOS Template.
        :param str template_type: The type of OOS Template.
        :param str template_version: Version of the OOS Template.
        :param str updated_by: The user who updated the template.
        :param str updated_date: The time when the template was updated.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "created_by", created_by)
        pulumi.set(__self__, "created_date", created_date)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "has_trigger", has_trigger)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "share_type", share_type)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "template_format", template_format)
        pulumi.set(__self__, "template_id", template_id)
        pulumi.set(__self__, "template_name", template_name)
        pulumi.set(__self__, "template_type", template_type)
        pulumi.set(__self__, "template_version", template_version)
        pulumi.set(__self__, "updated_by", updated_by)
        pulumi.set(__self__, "updated_date", updated_date)

    @property
    @pulumi.getter
    def category(self) -> str:
        """
        The category of template.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The creator of the template.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> str:
        """
        The template whose creation time is less than or equal to the specified time. The format is: YYYY-MM-DDThh:mm::ssZ.
        """
        return pulumi.get(self, "created_date")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the OOS Template.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="hasTrigger")
    def has_trigger(self) -> bool:
        """
        Is it triggered successfully.
        """
        return pulumi.get(self, "has_trigger")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the OOS Template. The value is same as template_name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="shareType")
    def share_type(self) -> str:
        """
        The sharing type of the template. Valid values: `Private`, `Public`.
        """
        return pulumi.get(self, "share_type")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="templateFormat")
    def template_format(self) -> str:
        """
        The format of the template. Valid values: `JSON`, `YAML`.
        """
        return pulumi.get(self, "template_format")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> str:
        """
        ID of the OOS Template resource.
        """
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> str:
        """
        Name of the OOS Template.
        """
        return pulumi.get(self, "template_name")

    @property
    @pulumi.getter(name="templateType")
    def template_type(self) -> str:
        """
        The type of OOS Template.
        """
        return pulumi.get(self, "template_type")

    @property
    @pulumi.getter(name="templateVersion")
    def template_version(self) -> str:
        """
        Version of the OOS Template.
        """
        return pulumi.get(self, "template_version")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> str:
        """
        The user who updated the template.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter(name="updatedDate")
    def updated_date(self) -> str:
        """
        The time when the template was updated.
        """
        return pulumi.get(self, "updated_date")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['StorageBundleArgs', 'StorageBundle']

@pulumi.input_type
class StorageBundleArgs:
    def __init__(__self__, *,
                 storage_bundle_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a StorageBundle resource.
        :param pulumi.Input[str] storage_bundle_name: The name of storage bundle.
        :param pulumi.Input[str] description: The description of storage bundle.
        """
        pulumi.set(__self__, "storage_bundle_name", storage_bundle_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="storageBundleName")
    def storage_bundle_name(self) -> pulumi.Input[str]:
        """
        The name of storage bundle.
        """
        return pulumi.get(self, "storage_bundle_name")

    @storage_bundle_name.setter
    def storage_bundle_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "storage_bundle_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of storage bundle.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _StorageBundleState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 storage_bundle_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering StorageBundle resources.
        :param pulumi.Input[str] description: The description of storage bundle.
        :param pulumi.Input[str] storage_bundle_name: The name of storage bundle.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if storage_bundle_name is not None:
            pulumi.set(__self__, "storage_bundle_name", storage_bundle_name)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of storage bundle.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="storageBundleName")
    def storage_bundle_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of storage bundle.
        """
        return pulumi.get(self, "storage_bundle_name")

    @storage_bundle_name.setter
    def storage_bundle_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_bundle_name", value)


class StorageBundle(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 storage_bundle_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Storage Gateway Storage Bundle resource.

        For information about Cloud Storage Gateway Storage Bundle and how to use it, see [What is Storage Bundle](https://www.alibabacloud.com/help/en/doc-detail/53972.htm).

        > **NOTE:** Available in v1.116.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cloudstoragegateway.StorageBundle("example", storage_bundle_name="example_value")
        ```

        ## Import

        Cloud Storage Gateway Storage Bundle can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cloudstoragegateway/storageBundle:StorageBundle example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of storage bundle.
        :param pulumi.Input[str] storage_bundle_name: The name of storage bundle.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StorageBundleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Storage Gateway Storage Bundle resource.

        For information about Cloud Storage Gateway Storage Bundle and how to use it, see [What is Storage Bundle](https://www.alibabacloud.com/help/en/doc-detail/53972.htm).

        > **NOTE:** Available in v1.116.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cloudstoragegateway.StorageBundle("example", storage_bundle_name="example_value")
        ```

        ## Import

        Cloud Storage Gateway Storage Bundle can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cloudstoragegateway/storageBundle:StorageBundle example <id>
        ```

        :param str resource_name: The name of the resource.
        :param StorageBundleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StorageBundleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 storage_bundle_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StorageBundleArgs.__new__(StorageBundleArgs)

            __props__.__dict__["description"] = description
            if storage_bundle_name is None and not opts.urn:
                raise TypeError("Missing required property 'storage_bundle_name'")
            __props__.__dict__["storage_bundle_name"] = storage_bundle_name
        super(StorageBundle, __self__).__init__(
            'alicloud:cloudstoragegateway/storageBundle:StorageBundle',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            storage_bundle_name: Optional[pulumi.Input[str]] = None) -> 'StorageBundle':
        """
        Get an existing StorageBundle resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of storage bundle.
        :param pulumi.Input[str] storage_bundle_name: The name of storage bundle.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StorageBundleState.__new__(_StorageBundleState)

        __props__.__dict__["description"] = description
        __props__.__dict__["storage_bundle_name"] = storage_bundle_name
        return StorageBundle(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of storage bundle.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="storageBundleName")
    def storage_bundle_name(self) -> pulumi.Output[str]:
        """
        The name of storage bundle.
        """
        return pulumi.get(self, "storage_bundle_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['InstanceAttachmentArgs', 'InstanceAttachment']

@pulumi.input_type
class InstanceAttachmentArgs:
    def __init__(__self__, *,
                 instance_name: pulumi.Input[str],
                 vpc_name: pulumi.Input[str],
                 vswitch_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a InstanceAttachment resource.
        :param pulumi.Input[str] instance_name: The name of the OTS instance.
        :param pulumi.Input[str] vpc_name: The name of attaching VPC to instance.
        :param pulumi.Input[str] vswitch_id: The ID of attaching VSwitch to instance.
        """
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "vpc_name", vpc_name)
        pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Input[str]:
        """
        The name of the OTS instance.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Input[str]:
        """
        The name of attaching VPC to instance.
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_name", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The ID of attaching VSwitch to instance.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.input_type
class _InstanceAttachmentState:
    def __init__(__self__, *,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_name: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering InstanceAttachment resources.
        :param pulumi.Input[str] instance_name: The name of the OTS instance.
        :param pulumi.Input[str] vpc_id: The ID of attaching VPC to instance.
        :param pulumi.Input[str] vpc_name: The name of attaching VPC to instance.
        :param pulumi.Input[str] vswitch_id: The ID of attaching VSwitch to instance.
        """
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the OTS instance.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of attaching VPC to instance.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of attaching VPC to instance.
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_name", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of attaching VSwitch to instance.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class InstanceAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 vpc_name: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource will help you to bind a VPC to an OTS instance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create an OTS instance
        foo_instance = alicloud.ots.Instance("fooInstance",
            description="for table",
            accessed_by="Vpc",
            tags={
                "Created": "TF",
                "For": "Building table",
            })
        foo_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        foo_network = alicloud.vpc.Network("fooNetwork", cidr_block="172.16.0.0/16")
        foo_switch = alicloud.vpc.Switch("fooSwitch",
            vpc_id=foo_network.id,
            vswitch_name="for-ots-instance",
            cidr_block="172.16.1.0/24",
            zone_id=foo_zones.zones[0].id)
        foo_instance_attachment = alicloud.ots.InstanceAttachment("fooInstanceAttachment",
            instance_name=foo_instance.name,
            vpc_name="attachment1",
            vswitch_id=foo_switch.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_name: The name of the OTS instance.
        :param pulumi.Input[str] vpc_name: The name of attaching VPC to instance.
        :param pulumi.Input[str] vswitch_id: The ID of attaching VSwitch to instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource will help you to bind a VPC to an OTS instance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create an OTS instance
        foo_instance = alicloud.ots.Instance("fooInstance",
            description="for table",
            accessed_by="Vpc",
            tags={
                "Created": "TF",
                "For": "Building table",
            })
        foo_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        foo_network = alicloud.vpc.Network("fooNetwork", cidr_block="172.16.0.0/16")
        foo_switch = alicloud.vpc.Switch("fooSwitch",
            vpc_id=foo_network.id,
            vswitch_name="for-ots-instance",
            cidr_block="172.16.1.0/24",
            zone_id=foo_zones.zones[0].id)
        foo_instance_attachment = alicloud.ots.InstanceAttachment("fooInstanceAttachment",
            instance_name=foo_instance.name,
            vpc_name="attachment1",
            vswitch_id=foo_switch.id)
        ```

        :param str resource_name: The name of the resource.
        :param InstanceAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 vpc_name: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceAttachmentArgs.__new__(InstanceAttachmentArgs)

            if instance_name is None and not opts.urn:
                raise TypeError("Missing required property 'instance_name'")
            __props__.__dict__["instance_name"] = instance_name
            if vpc_name is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_name'")
            __props__.__dict__["vpc_name"] = vpc_name
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["vpc_id"] = None
        super(InstanceAttachment, __self__).__init__(
            'alicloud:ots/instanceAttachment:InstanceAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_name: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vpc_name: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'InstanceAttachment':
        """
        Get an existing InstanceAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_name: The name of the OTS instance.
        :param pulumi.Input[str] vpc_id: The ID of attaching VPC to instance.
        :param pulumi.Input[str] vpc_name: The name of attaching VPC to instance.
        :param pulumi.Input[str] vswitch_id: The ID of attaching VSwitch to instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceAttachmentState.__new__(_InstanceAttachmentState)

        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        __props__.__dict__["vswitch_id"] = vswitch_id
        return InstanceAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[str]:
        """
        The name of the OTS instance.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of attaching VPC to instance.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[str]:
        """
        The name of attaching VPC to instance.
        """
        return pulumi.get(self, "vpc_name")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The ID of attaching VSwitch to instance.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetSecretParametersResult',
    'AwaitableGetSecretParametersResult',
    'get_secret_parameters',
    'get_secret_parameters_output',
]

@pulumi.output_type
class GetSecretParametersResult:
    """
    A collection of values returned by getSecretParameters.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, name_regex=None, names=None, output_file=None, parameters=None, resource_group_id=None, secret_parameter_name=None, sort_field=None, sort_order=None, tags=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if parameters and not isinstance(parameters, list):
            raise TypeError("Expected argument 'parameters' to be a list")
        pulumi.set(__self__, "parameters", parameters)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if secret_parameter_name and not isinstance(secret_parameter_name, str):
            raise TypeError("Expected argument 'secret_parameter_name' to be a str")
        pulumi.set(__self__, "secret_parameter_name", secret_parameter_name)
        if sort_field and not isinstance(sort_field, str):
            raise TypeError("Expected argument 'sort_field' to be a str")
        pulumi.set(__self__, "sort_field", sort_field)
        if sort_order and not isinstance(sort_order, str):
            raise TypeError("Expected argument 'sort_order' to be a str")
        pulumi.set(__self__, "sort_order", sort_order)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def parameters(self) -> Sequence['outputs.GetSecretParametersParameterResult']:
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="secretParameterName")
    def secret_parameter_name(self) -> Optional[str]:
        return pulumi.get(self, "secret_parameter_name")

    @property
    @pulumi.getter(name="sortField")
    def sort_field(self) -> Optional[str]:
        return pulumi.get(self, "sort_field")

    @property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[str]:
        return pulumi.get(self, "sort_order")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "tags")


class AwaitableGetSecretParametersResult(GetSecretParametersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecretParametersResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            parameters=self.parameters,
            resource_group_id=self.resource_group_id,
            secret_parameter_name=self.secret_parameter_name,
            sort_field=self.sort_field,
            sort_order=self.sort_order,
            tags=self.tags)


def get_secret_parameters(enable_details: Optional[bool] = None,
                          ids: Optional[Sequence[str]] = None,
                          name_regex: Optional[str] = None,
                          output_file: Optional[str] = None,
                          resource_group_id: Optional[str] = None,
                          secret_parameter_name: Optional[str] = None,
                          sort_field: Optional[str] = None,
                          sort_order: Optional[str] = None,
                          tags: Optional[Mapping[str, Any]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecretParametersResult:
    """
    This data source provides the Oos Secret Parameters of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.147.0+.


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Secret Parameter IDs.
    :param str name_regex: A regex string to filter results by Secret Parameter name.
    :param str resource_group_id: The ID of the Resource Group.
    :param str secret_parameter_name: The name of the encryption parameter.
    :param Mapping[str, Any] tags: The tag of the resource.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['secretParameterName'] = secret_parameter_name
    __args__['sortField'] = sort_field
    __args__['sortOrder'] = sort_order
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:oos/getSecretParameters:getSecretParameters', __args__, opts=opts, typ=GetSecretParametersResult).value

    return AwaitableGetSecretParametersResult(
        enable_details=__ret__.enable_details,
        id=__ret__.id,
        ids=__ret__.ids,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        output_file=__ret__.output_file,
        parameters=__ret__.parameters,
        resource_group_id=__ret__.resource_group_id,
        secret_parameter_name=__ret__.secret_parameter_name,
        sort_field=__ret__.sort_field,
        sort_order=__ret__.sort_order,
        tags=__ret__.tags)


@_utilities.lift_output_func(get_secret_parameters)
def get_secret_parameters_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                                 ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                 output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                 resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 secret_parameter_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 sort_field: Optional[pulumi.Input[Optional[str]]] = None,
                                 sort_order: Optional[pulumi.Input[Optional[str]]] = None,
                                 tags: Optional[pulumi.Input[Optional[Mapping[str, Any]]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSecretParametersResult]:
    """
    This data source provides the Oos Secret Parameters of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.147.0+.


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Secret Parameter IDs.
    :param str name_regex: A regex string to filter results by Secret Parameter name.
    :param str resource_group_id: The ID of the Resource Group.
    :param str secret_parameter_name: The name of the encryption parameter.
    :param Mapping[str, Any] tags: The tag of the resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetOrganizationsResult',
    'AwaitableGetOrganizationsResult',
    'get_organizations',
    'get_organizations_output',
]

@pulumi.output_type
class GetOrganizationsResult:
    """
    A collection of values returned by getOrganizations.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, organizations=None, output_file=None, real_pk=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if organizations and not isinstance(organizations, list):
            raise TypeError("Expected argument 'organizations' to be a list")
        pulumi.set(__self__, "organizations", organizations)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if real_pk and not isinstance(real_pk, str):
            raise TypeError("Expected argument 'real_pk' to be a str")
        pulumi.set(__self__, "real_pk", real_pk)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter
    def organizations(self) -> Sequence['outputs.GetOrganizationsOrganizationResult']:
        return pulumi.get(self, "organizations")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="realPk")
    def real_pk(self) -> Optional[str]:
        return pulumi.get(self, "real_pk")


class AwaitableGetOrganizationsResult(GetOrganizationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrganizationsResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            organizations=self.organizations,
            output_file=self.output_file,
            real_pk=self.real_pk)


def get_organizations(ids: Optional[Sequence[str]] = None,
                      name_regex: Optional[str] = None,
                      output_file: Optional[str] = None,
                      real_pk: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrganizationsResult:
    """
    This data source provides the Rdc Organizations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.137.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "tf-testAccOrganizations-Organizations"
    default = alicloud.rdc.Organization("default",
        organization_name=name,
        source=name)
    ids = alicloud.rdc.get_organizations_output(ids=[default.id])
    pulumi.export("rdcOrganizationId1", ids.id)
    name_regex = alicloud.rdc.get_organizations(name_regex="^my-Organization")
    pulumi.export("rdcOrganizationId2", name_regex.id)
    ```


    :param Sequence[str] ids: A list of Organization IDs.
    :param str name_regex: A regex string to filter results by Organization name.
    :param str real_pk: User pk, not required, only required when the ak used by the calling interface is inconsistent with the user pk
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['realPk'] = real_pk
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:rdc/getOrganizations:getOrganizations', __args__, opts=opts, typ=GetOrganizationsResult).value

    return AwaitableGetOrganizationsResult(
        id=__ret__.id,
        ids=__ret__.ids,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        organizations=__ret__.organizations,
        output_file=__ret__.output_file,
        real_pk=__ret__.real_pk)


@_utilities.lift_output_func(get_organizations)
def get_organizations_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                             real_pk: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOrganizationsResult]:
    """
    This data source provides the Rdc Organizations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.137.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "tf-testAccOrganizations-Organizations"
    default = alicloud.rdc.Organization("default",
        organization_name=name,
        source=name)
    ids = alicloud.rdc.get_organizations_output(ids=[default.id])
    pulumi.export("rdcOrganizationId1", ids.id)
    name_regex = alicloud.rdc.get_organizations(name_regex="^my-Organization")
    pulumi.export("rdcOrganizationId2", name_regex.id)
    ```


    :param Sequence[str] ids: A list of Organization IDs.
    :param str name_regex: A regex string to filter results by Organization name.
    :param str real_pk: User pk, not required, only required when the ak used by the calling interface is inconsistent with the user pk
    """
    ...
